/** @file el1xxx_device.c Implementation of the device handler of the EL1xxx devices for the SOEM master. */

#include "stdincludes.h"
#include "soem_devices.h"

/* {{{ EL1004 */
#define EL1004_NCHAN            4
#define EL1004_DEV_ID           0x03ec3052
#define EL1004_DEV_STR          "EL1004"

typedef struct PACKED
{
    uint8_t inbits;
} in_EL1004t;

static double el1004_read(IoInstance *io_instance) {
    DeviceInstance *soem_di = (DeviceInstance *)io_instance->device;
    const in_EL1004t *input_data = soem_di->input_address;

    return input_data->inbits;
}

static const InputIoDefinition el1004_din = {
    {DK_DIN, "din", EL1004_NCHAN}, &el1004_read
};

static const InputIoDefinition *el1004_inputs[] = {&el1004_din, NULL};
static const OutputIoDefinition *el1004_outputs[] = {NULL};

const DeviceDefinition el1004_device = {
    EL1004_DEV_STR,
    el1004_inputs, el1004_outputs,
    sizeof(DeviceInstance),
    NULL,
    EL1004_DEV_ID,
};
/* }}} */
/* {{{ EL1008 */
#define EL1008_NCHAN            8
#define EL1008_DEV_ID           0x03f03052
#define EL1008_DEV_STR          "EL1008"

typedef struct PACKED
{
    uint8_t inbits;
} in_EL1008t;

static double el1008_read(IoInstance *io_instance) {
    DeviceInstance *soem_di = (DeviceInstance *)io_instance->device;
    const in_EL1008t *input_data = soem_di->input_address;

    return input_data->inbits;
}

static const InputIoDefinition el1008_din = {
    {DK_DIN, "din", EL1008_NCHAN}, &el1008_read
};

static const InputIoDefinition *el1008_inputs[] = {&el1008_din, NULL};
static const OutputIoDefinition *el1008_outputs[] = {NULL};

const DeviceDefinition el1008_device = {
    EL1008_DEV_STR,
    el1008_inputs, el1008_outputs,
    sizeof(DeviceInstance),
    NULL,
    EL1008_DEV_ID,
};
/* }}} */
/* {{{ EL1014 */
#define EL1014_NCHAN            4
#define EL1014_DEV_ID           0x03f63052
#define EL1014_DEV_STR          "EL1014"

typedef struct PACKED
{
    uint8_t inbits;
} in_EL1014t;

static double el1014_read(IoInstance *io_instance) {
    DeviceInstance *soem_di = (DeviceInstance *)io_instance->device;
    const in_EL1014t *input_data = soem_di->input_address;

    return input_data->inbits;
};

static const InputIoDefinition el1014_din = {
    {DK_DIN, "din", EL1014_NCHAN}, &el1014_read
};

static const InputIoDefinition *el1014_inputs[] = {&el1014_din, NULL};
static const OutputIoDefinition *el1014_outputs[] = {NULL};

const DeviceDefinition el1014_device = {
    EL1014_DEV_STR,
    el1014_inputs, el1014_outputs,
    sizeof(DeviceInstance),
    NULL,
    EL1014_DEV_ID,
};
/* }}} */
/* {{{ EL1018 */
#define EL1018_NCHAN            8
#define EL1018_DEV_ID           0x03fa3052
#define EL1018_DEV_STR          "EL1018"

typedef struct PACKED
{
    uint8_t inbits;
} in_EL1018t;

static double el1018_read(IoInstance *io_instance) {
    DeviceInstance *soem_di = (DeviceInstance *)io_instance->device;
    const in_EL1018t *input_data = soem_di->input_address;

    return input_data->inbits;
}

static const InputIoDefinition el1018_din = {
    {DK_DIN, "din", EL1018_NCHAN}, &el1018_read
};

static const InputIoDefinition *el1018_inputs[] = {&el1018_din, NULL};
static const OutputIoDefinition *el1018_outputs[] = {NULL};

const DeviceDefinition el1018_device = {
    EL1018_DEV_STR,
    el1018_inputs, el1018_outputs,
    sizeof(DeviceInstance),
    NULL,
    EL1018_DEV_ID,
};
/* }}} */

/* {{{ EL1819 */
#define EL1819_NCHAN            16
#define EL1819_DEV_ID           0x071b3052
#define EL1819_DEV_STR          "EL1819"

typedef struct PACKED
{
    uint16_t inbits;
} in_EL1819t;

static double el1819_read(IoInstance *io_instance) {
    DeviceInstance *soem_di = (DeviceInstance *)io_instance->device;
    const in_EL1819t *input_data = soem_di->input_address;

    return input_data->inbits;
}

static const InputIoDefinition el1819_din = {
    {DK_DIN, "din", EL1819_NCHAN}, &el1819_read
};

static const InputIoDefinition *el1819_inputs[] = {&el1819_din, NULL};
static const OutputIoDefinition *el1819_outputs[] = {NULL};

const DeviceDefinition el1819_device = {
    EL1819_DEV_STR,
    el1819_inputs, el1819_outputs,
    sizeof(DeviceInstance),
    NULL,
    EL1819_DEV_ID,
};
/* }}} */
