/** @file error_storage.h Data and functions to store error messages while performing data IO. */

#ifndef ERROR_STORAGE_H
#define ERROR_STORAGE_H

/** Storage of a detected error. */
struct ErrorStorageStruct {
    const char *message; /**< Statically allocated message, or \c NULL. */
    int16_t group_index; /**< If non-negative, the group index where the error was found. */
    BOOL error;          /**< If set, the message is a real error, else it is a warning. */
};
typedef struct ErrorStorageStruct ErrorStorage;

void InitErrorStorage(ErrorStorage *es);
void SetWarning(ErrorStorage *es, const char *message, int16_t group_index);
void SetError(ErrorStorage *es, const char *message, int16_t group_index);
void CopyErrorStorage(ErrorStorage *dst, const ErrorStorage *src);

/**
 * Test whether the storage has a message at all.
 * @param es Error storage to test.
 * @return Whether the provided storage has a message.
 */
#define HasMessage(es) ((es)->message != NULL)

/**
 * Test whether the storage contains an error.
 * @param es Error storage to test.
 * @return Whether the provided storage contains an error. Note that \c FALSE may
 *      mean that there is no message or it has a warning message. Use #HasMessage
 *      to differentiate between these possibilities.
 */
#define HasErrorMessage(es) (HasMessage(es) && (es)->error)

#endif
