/** @file memory.h Memory allocation related functions, */

#ifndef MEMORY_H
#define MEMORY_H

#include <pthread.h>

/* Local definitions. */
typedef struct MemoryStruct Memory;

/** Interface definition of the memory manager. */
struct MemoryStruct {
    pthread_mutex_t lock;  /**< Mutual exclusive access to the memory data. */
    uint8_t *free_memory;  /**< Memory not yet given away for use. */
    size_t remaining_size; /**< Amount of memory still available for use. */
    void *base;            /**< Base address of the allocated memory. */
};

void MemoryInit(Memory *mem);
void MemorySetMemory(Memory *mem, void *base, size_t size);
void *MemoryDestroy(Memory *mem);

void *MemoryAllocate(Memory *mem, size_t size);

void *MemoryAllocateAll(Memory *mem, size_t *max_size);
void MemoryAllocateSetNeeded(Memory *mem, void *start, size_t size);

#endif

