/** @file nanotime.h Nano-second time computing. */

#ifndef NANO_TIME_H
#define NANO_TIME_H

#ifndef USE_GETTIMEOFDAY
#include <time.h>
#endif

/** Number of nano seconds in one second. */
#define ONE_SEC 1000000000L

/** Data type for storing time in nano-seconds. */
typedef struct timespec NanoTime;

NanoTime MakeNanos(uint64_t secs, uint32_t nanos);
NanoTime MakeNano64(uint64_t nsecs);
NanoTime NowNanos(void);
NanoTime AddNanos(const NanoTime *nt1, const NanoTime *nt2);
void IncreaseNano(NanoTime *nt, const NanoTime *add);
int CmpNanos(const NanoTime *ln, const NanoTime *rn);
void CopyNanos(NanoTime *dst, const NanoTime *src);
double ConvertNano(const NanoTime *nt);

#ifdef DBG_NANOTIME
double GetRelativeTime(const NanoTime *nanos);
double GetRelativeCurrent(void);
#endif

#endif
