/** @file signal_group.h Storage of measurement data, and mapping of signals to Matlab matrices. */

#ifndef SIGNAL_GROUP_H
#define SIGNAL_GROUP_H

#include "soem_devices.h"

/** Definition of a signal in a signal group. */
struct SignalSpecificationStruct {
    const char *dev_name;   /** Name of the device to use (if specified, else \c NULL). */
    size_t dev_number;      /**< Number of the device to use. */

    IoKind kind;            /**< Kind of the io access point, used if #dev_name is \c NULL. */
    const char *io_name;    /**< Name of the io access point, used if #dev_name is not \c NULL. */
    ssize_t channel_number; /**< Channel to use of the io access point, negative means 'everything'. */
};
typedef struct SignalSpecificationStruct SignalSpecification;


struct SignalGroupStruct {
    uint32_t buffer_size;     /**< Number of samples that fits in a single buffer. */
    uint32_t buffer_count;    /**< Number of buffers for the signal group. */
    uint32_t buffer_prewrite; /**< Number of samples to pre-write (only used for input signal groups). */

    const SignalSpecification *signals; /**< Specification of the signals in the group. */
    uint16_t signal_count;              /**< Number of signals in the group. */
};
typedef struct SignalGroupStruct SignalGroup;

#endif
