
/** @file stdincludes.h Standard definitions for the code. */

#ifndef STDINCLUDES_H
#define STDINCLUDES_H

typedef unsigned char BOOL;
#define TRUE 1
#define FALSE 0

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <inttypes.h>

/** Macro to enforce packed structure for gcc. */
#ifndef PACKED
#define PACKED __attribute__ ((__packed__))
#endif

/** Macro denoting the function does not return from the call. */
#define NO_RETURN __attribute__ ((noreturn))

void not_reached(const char *fname, int line) NO_RETURN;

/** Macro denoting execution at its point in the code should never happen. */
#define NOT_REACHED() not_reached(__FILE__, __LINE__)

/**
 * gcc alignment meory requirement implementation.
 */
#define TYPE_ALIGNMENT(type) __alignof__(type)

/**
 * Get length of a literal array.
 * @param array Array to inspect.
 * @return Length of the array.
 */
#define LENGTH_OF(array) (sizeof(array) / sizeof((array)[0]))


#endif
