/** @file test_bufferread.c Tests for the 'read column of buffer' interface. */

/* gcc -o test_bufferread -Wall -g -DTEST_BUFFERREAD -Isrc src/test_bufferread.c src/buffer.c */

#ifdef TEST_BUFFERREAD

#include "stdincludes.h"
#include "buffer.h"

static void PrintResult(const char *msg, int v)
{
    printf("%s: %s\n", msg, v ? "ok" : "                    ERROR");
}

void TestBufferRead(void)
{
    double data[50];
    Buffer b;
    BufferRead br;
    int i, s, c;
    double *dp;

    for (i = 0; i < LENGTH_OF(data); i++) data[i] = i;
    InitBuffer(&b, data, 5, 3);
    InitBufferRead(&br, 3);

    for (s = 0; s < 5; s += 3) { /* Start column in buffer. */
        printf("\nRead s%d\n", s);
        b.used = 3;
        b.start = s;

        SetupBufferRead(&br, &b);
        /* 3 used cols */
        dp = ReadFromBuffer(&br);
        c = s;
        PrintResult("1st col read", dp == data + c * 3 && BufferReadHasUnread(&br));

        /* 2 used cols */
        dp = ReadFromBuffer(&br);
        c = (s + 1) % 5;
        PrintResult("2nd col read", dp == data + c * 3 && BufferReadHasUnread(&br));

        /* 1 used cols */
        dp = ReadFromBuffer(&br);
        c = (s + 2) % 5;
        PrintResult("3rd col read", dp == data + c * 3 && !BufferReadHasUnread(&br));

        /* 0 used cols */
        dp = ReadFromBuffer(&br);
        c = (s + 2) % 5;
        PrintResult("4th col read", dp == data + c * 3 && !BufferReadHasUnread(&br));

        /* 0 used cols */
        dp = ReadFromBuffer(&br);
        c = (s + 2) % 5;
        PrintResult("5th col read", dp == data + c * 3 && !BufferReadHasUnread(&br));
    }
}


int main(void)
{
    TestBufferRead();
    return 0;
}

#endif
