/** @file test_bufferwrite.c Test code for writing to a buffer. */

/* gcc -o test_bufferwrite -Wall -g -DTEST_BUFFERWRITE -Isrc src/test_bufferwrite.c src/buffer.c */

#ifdef TEST_BUFFERWRITE

#include "stdincludes.h"
#include "buffer.h"

void BWtest(Buffer *b, BufferWrite *bw, int prewrite, int pre_sample, int samples,
            int first_col, int num_cols)
{
    int s, i, c;
    double *pd;

    printf("\nBWtest pw%d ps%d s%d\n", prewrite, pre_sample, samples);

    InitBufferWrite(bw, 3, prewrite);
    SetupBufferWrite(bw, b);

    i = TRUE;
    c = 0;
    for (s = 0; s < pre_sample; s++) {
        pd = BufferWritePrewrite(bw);
        i &= (pd == b->data + c * 3);
        if (prewrite > 0) c = (c + 1) % 5;
    }
    if (pre_sample > 0) printf("Pre-sample: %s\n", i ? "ok" : "           ERROR");

    i = TRUE;
    for (s = 0; s < samples; s++) {
        pd = BufferWriteReal(bw);
        i &= (pd == b->data + c * 3);
        c = (c + 1) % 5;
    }
    printf("Write: %s\n", i ? "ok" : "                 ERROR");

    FinishBufferWrite(bw);
    i = (b->start == first_col) && (b->used == num_cols);
    printf("Finish: %s\n", i ? "ok" : "                 ERROR");
}

void TestBufferWrite(void)
{
    double data[50];
    Buffer b;
    BufferWrite bw;

    InitBuffer(&b, data, 5, 3);

    BWtest(&b, &bw, 0, 0, 1,  0, 1);
    BWtest(&b, &bw, 0, 0, 5,  0, 5);
    BWtest(&b, &bw, 2, 0, 2,  0, 2);
    BWtest(&b, &bw, 3, 1, 2,  0, 3);
    BWtest(&b, &bw, 3, 7, 2,  4, 5);
}

int main(void)
{
    TestBufferWrite();
    return 0;
}

#endif
