/** @file triggerblock.h Trigger definitions. */

#ifndef TRIGGER_BLOCK_H
#define TRIGGER_BLOCK_H

/** Type of trigger condition when value reaches or crosses the treshold. */
enum TriggerBlockTypeEnum {
    TT_NONE,      /**< Never trigger. */
    TT_RISING,    /**< Trigger only on rising flank. */
    TT_DECLINING, /**< Trigger only on declining flank. */
    TT_REACHING,  /**< Trigger when treshold is reached (from either side). */
};
typedef enum TriggerBlockTypeEnum TriggerBlockType;

/** Definition of a trigger. */
struct TriggerBlockStruct {
    TriggerBlockType trigger_type; /**< Trigger condition. */
    double treshold;        /**< Treshold value of the trigger. */
    double previous_sample; /**< Previous sample for deciding triggering. */

    size_t copy_count;      /**< Number of samples to copy. */
    size_t counter;         /**< Running counter for copying samples (decrements to 0). */
};
typedef struct TriggerBlockStruct TriggerBlock;

void TriggerBlockInit(TriggerBlock *t);
void TriggerBlockSetPoint(TriggerBlock *t, double treshold, BOOL trigger_up, BOOL trigger_down);
void TriggerBlockSetCount(TriggerBlock *t, ssize_t copy_count);
void TriggerBlockAddSample(TriggerBlock *t, double sample);

/**
 * Test whether the trigger is enabled.
 * @param t Trigger to test.
 * @return Whether the trigger is enabled.
 */
#define TriggerBlockEnabled(t) ((t)->counter > 0)

#endif
